# Stress Test Assurance Case

This document exercises a large assurance case with many packages and elements.

## SACM/Mermaid View

<!-- verocase sacm/mermaid * -->
stale sacm content
<!-- end verocase -->

## GSN/Mermaid View

<!-- verocase gsn/mermaid * -->
stale gsn content
<!-- end verocase -->

## LTAC/Markdown View

<!-- verocase ltac/markdown * -->
stale ltac content
<!-- end verocase -->

## Element Details

<!-- verocase element G1 -->
<!-- end verocase -->

Stub for Claim G1.

<!-- verocase element Xscope -->
<!-- end verocase -->

Stub for Context Xscope.

<!-- verocase element Asys -->
<!-- end verocase -->

Stub for Assumption Asys.

<!-- verocase element Esys1 -->
<!-- end verocase -->

Stub for Evidence Esys1.

<!-- verocase element Sdecomp -->
<!-- end verocase -->

Stub for Strategy Sdecomp.

<!-- verocase element Scomps -->
<!-- end verocase -->

Stub for Strategy Scomps.

<!-- verocase element L1top -->
<!-- end verocase -->

Stub for Claim L1top.

<!-- verocase element L1Xctx -->
<!-- end verocase -->

Stub for Context L1Xctx.

<!-- verocase element L1Esh1 -->
<!-- end verocase -->

Stub for Evidence L1Esh1.

<!-- verocase element L1Esh2 -->
<!-- end verocase -->

Stub for Evidence L1Esh2.

<!-- verocase element L1Smain -->
<!-- end verocase -->

Stub for Strategy L1Smain.

<!-- verocase element L1G2 -->
<!-- end verocase -->

Stub for Claim L1G2.

<!-- verocase element L1S2 -->
<!-- end verocase -->

Stub for Strategy L1S2.

<!-- verocase element L1G3 -->
<!-- end verocase -->

Stub for Claim L1G3.

<!-- verocase element L1S3 -->
<!-- end verocase -->

Stub for Strategy L1S3.

<!-- verocase element L1G4 -->
<!-- end verocase -->

Stub for Claim L1G4.

<!-- verocase element L1Edeep -->
<!-- end verocase -->

Stub for Evidence L1Edeep.

<!-- verocase element L1G4b -->
<!-- end verocase -->

Stub for Claim L1G4b.

<!-- verocase element L1G3b -->
<!-- end verocase -->

Stub for Claim L1G3b.

<!-- verocase element L1G3c -->
<!-- end verocase -->

Stub for Claim L1G3c.

<!-- verocase element L1J1 -->
<!-- end verocase -->

Stub for Justification L1J1.

<!-- verocase element L1G2b -->
<!-- end verocase -->

Stub for Claim L1G2b.

<!-- verocase element L1S2b -->
<!-- end verocase -->

Stub for Strategy L1S2b.

<!-- verocase element L1G3d -->
<!-- end verocase -->

Stub for Claim L1G3d.

<!-- verocase element L1G3e -->
<!-- end verocase -->

Stub for Claim L1G3e.

<!-- verocase element L1E2 -->
<!-- end verocase -->

Stub for Evidence L1E2.

<!-- verocase element L1Gbr1 -->
<!-- end verocase -->

Stub for Claim L1Gbr1.

<!-- verocase element L1Gbr1a -->
<!-- end verocase -->

Stub for Claim L1Gbr1a.

<!-- verocase element L1Ebr1 -->
<!-- end verocase -->

Stub for Evidence L1Ebr1.

<!-- verocase element L1Gbr1b -->
<!-- end verocase -->

Stub for Claim L1Gbr1b.

<!-- verocase element L1Gbr2 -->
<!-- end verocase -->

Stub for Claim L1Gbr2.

<!-- verocase element L1Gbr2a -->
<!-- end verocase -->

Stub for Claim L1Gbr2a.

<!-- verocase element L1Ebr2 -->
<!-- end verocase -->

Stub for Evidence L1Ebr2.

<!-- verocase element L1Gbr2b -->
<!-- end verocase -->

Stub for Claim L1Gbr2b.

<!-- verocase element L1Gbr3 -->
<!-- end verocase -->

Stub for Claim L1Gbr3.

<!-- verocase element L1Gbr3a -->
<!-- end verocase -->

Stub for Claim L1Gbr3a.

<!-- verocase element L1Ebr3 -->
<!-- end verocase -->

Stub for Evidence L1Ebr3.

<!-- verocase element L1Gbr3b -->
<!-- end verocase -->

Stub for Claim L1Gbr3b.

<!-- verocase element L1Gbr4 -->
<!-- end verocase -->

Stub for Claim L1Gbr4.

<!-- verocase element L1Gbr4a -->
<!-- end verocase -->

Stub for Claim L1Gbr4a.

<!-- verocase element L1Ebr4 -->
<!-- end verocase -->

Stub for Evidence L1Ebr4.

<!-- verocase element L1Gbr4b -->
<!-- end verocase -->

Stub for Claim L1Gbr4b.

<!-- verocase element L1Gbr5 -->
<!-- end verocase -->

Stub for Claim L1Gbr5.

<!-- verocase element L1Gbr5a -->
<!-- end verocase -->

Stub for Claim L1Gbr5a.

<!-- verocase element L1Ebr5 -->
<!-- end verocase -->

Stub for Evidence L1Ebr5.

<!-- verocase element L1Gbr5b -->
<!-- end verocase -->

Stub for Claim L1Gbr5b.

<!-- verocase element L1Gbr6 -->
<!-- end verocase -->

Stub for Claim L1Gbr6.

<!-- verocase element L1Gbr6a -->
<!-- end verocase -->

Stub for Claim L1Gbr6a.

<!-- verocase element L1Ebr6 -->
<!-- end verocase -->

Stub for Evidence L1Ebr6.

<!-- verocase element L1Gbr6b -->
<!-- end verocase -->

Stub for Claim L1Gbr6b.

<!-- verocase element L1Gbr7 -->
<!-- end verocase -->

Stub for Claim L1Gbr7.

<!-- verocase element L1Gbr7a -->
<!-- end verocase -->

Stub for Claim L1Gbr7a.

<!-- verocase element L1Ebr7 -->
<!-- end verocase -->

Stub for Evidence L1Ebr7.

<!-- verocase element L1Gbr7b -->
<!-- end verocase -->

Stub for Claim L1Gbr7b.

<!-- verocase element L1Gbr8 -->
<!-- end verocase -->

Stub for Claim L1Gbr8.

<!-- verocase element L1Gbr8a -->
<!-- end verocase -->

Stub for Claim L1Gbr8a.

<!-- verocase element L1Ebr8 -->
<!-- end verocase -->

Stub for Evidence L1Ebr8.

<!-- verocase element L1Gbr8b -->
<!-- end verocase -->

Stub for Claim L1Gbr8b.

<!-- verocase element L2top -->
<!-- end verocase -->

Stub for Claim L2top.

<!-- verocase element L2Xctx -->
<!-- end verocase -->

Stub for Context L2Xctx.

<!-- verocase element L2Esh1 -->
<!-- end verocase -->

Stub for Evidence L2Esh1.

<!-- verocase element L2Esh2 -->
<!-- end verocase -->

Stub for Evidence L2Esh2.

<!-- verocase element L2Smain -->
<!-- end verocase -->

Stub for Strategy L2Smain.

<!-- verocase element L2G2 -->
<!-- end verocase -->

Stub for Claim L2G2.

<!-- verocase element L2S2 -->
<!-- end verocase -->

Stub for Strategy L2S2.

<!-- verocase element L2G3 -->
<!-- end verocase -->

Stub for Claim L2G3.

<!-- verocase element L2S3 -->
<!-- end verocase -->

Stub for Strategy L2S3.

<!-- verocase element L2G4 -->
<!-- end verocase -->

Stub for Claim L2G4.

<!-- verocase element L2Edeep -->
<!-- end verocase -->

Stub for Evidence L2Edeep.

<!-- verocase element L2G4b -->
<!-- end verocase -->

Stub for Claim L2G4b.

<!-- verocase element L2G3b -->
<!-- end verocase -->

Stub for Claim L2G3b.

<!-- verocase element L2G3c -->
<!-- end verocase -->

Stub for Claim L2G3c.

<!-- verocase element L2J1 -->
<!-- end verocase -->

Stub for Justification L2J1.

<!-- verocase element L2G2b -->
<!-- end verocase -->

Stub for Claim L2G2b.

<!-- verocase element L2S2b -->
<!-- end verocase -->

Stub for Strategy L2S2b.

<!-- verocase element L2G3d -->
<!-- end verocase -->

Stub for Claim L2G3d.

<!-- verocase element L2G3e -->
<!-- end verocase -->

Stub for Claim L2G3e.

<!-- verocase element L2E2 -->
<!-- end verocase -->

Stub for Evidence L2E2.

<!-- verocase element L2Gbr1 -->
<!-- end verocase -->

Stub for Claim L2Gbr1.

<!-- verocase element L2Gbr1a -->
<!-- end verocase -->

Stub for Claim L2Gbr1a.

<!-- verocase element L2Ebr1 -->
<!-- end verocase -->

Stub for Evidence L2Ebr1.

<!-- verocase element L2Gbr1b -->
<!-- end verocase -->

Stub for Claim L2Gbr1b.

<!-- verocase element L2Gbr2 -->
<!-- end verocase -->

Stub for Claim L2Gbr2.

<!-- verocase element L2Gbr2a -->
<!-- end verocase -->

Stub for Claim L2Gbr2a.

<!-- verocase element L2Ebr2 -->
<!-- end verocase -->

Stub for Evidence L2Ebr2.

<!-- verocase element L2Gbr2b -->
<!-- end verocase -->

Stub for Claim L2Gbr2b.

<!-- verocase element L2Gbr3 -->
<!-- end verocase -->

Stub for Claim L2Gbr3.

<!-- verocase element L2Gbr3a -->
<!-- end verocase -->

Stub for Claim L2Gbr3a.

<!-- verocase element L2Ebr3 -->
<!-- end verocase -->

Stub for Evidence L2Ebr3.

<!-- verocase element L2Gbr3b -->
<!-- end verocase -->

Stub for Claim L2Gbr3b.

<!-- verocase element L2Gbr4 -->
<!-- end verocase -->

Stub for Claim L2Gbr4.

<!-- verocase element L2Gbr4a -->
<!-- end verocase -->

Stub for Claim L2Gbr4a.

<!-- verocase element L2Ebr4 -->
<!-- end verocase -->

Stub for Evidence L2Ebr4.

<!-- verocase element L2Gbr4b -->
<!-- end verocase -->

Stub for Claim L2Gbr4b.

<!-- verocase element L2Gbr5 -->
<!-- end verocase -->

Stub for Claim L2Gbr5.

<!-- verocase element L2Gbr5a -->
<!-- end verocase -->

Stub for Claim L2Gbr5a.

<!-- verocase element L2Ebr5 -->
<!-- end verocase -->

Stub for Evidence L2Ebr5.

<!-- verocase element L2Gbr5b -->
<!-- end verocase -->

Stub for Claim L2Gbr5b.

<!-- verocase element L2Gbr6 -->
<!-- end verocase -->

Stub for Claim L2Gbr6.

<!-- verocase element L2Gbr6a -->
<!-- end verocase -->

Stub for Claim L2Gbr6a.

<!-- verocase element L2Ebr6 -->
<!-- end verocase -->

Stub for Evidence L2Ebr6.

<!-- verocase element L2Gbr6b -->
<!-- end verocase -->

Stub for Claim L2Gbr6b.

<!-- verocase element L2Gbr7 -->
<!-- end verocase -->

Stub for Claim L2Gbr7.

<!-- verocase element L2Gbr7a -->
<!-- end verocase -->

Stub for Claim L2Gbr7a.

<!-- verocase element L2Ebr7 -->
<!-- end verocase -->

Stub for Evidence L2Ebr7.

<!-- verocase element L2Gbr7b -->
<!-- end verocase -->

Stub for Claim L2Gbr7b.

<!-- verocase element L2Gbr8 -->
<!-- end verocase -->

Stub for Claim L2Gbr8.

<!-- verocase element L2Gbr8a -->
<!-- end verocase -->

Stub for Claim L2Gbr8a.

<!-- verocase element L2Ebr8 -->
<!-- end verocase -->

Stub for Evidence L2Ebr8.

<!-- verocase element L2Gbr8b -->
<!-- end verocase -->

Stub for Claim L2Gbr8b.

<!-- verocase element L3top -->
<!-- end verocase -->

Stub for Claim L3top.

<!-- verocase element L3Xctx -->
<!-- end verocase -->

Stub for Context L3Xctx.

<!-- verocase element L3Esh1 -->
<!-- end verocase -->

Stub for Evidence L3Esh1.

<!-- verocase element L3Esh2 -->
<!-- end verocase -->

Stub for Evidence L3Esh2.

<!-- verocase element L3Smain -->
<!-- end verocase -->

Stub for Strategy L3Smain.

<!-- verocase element L3G2 -->
<!-- end verocase -->

Stub for Claim L3G2.

<!-- verocase element L3S2 -->
<!-- end verocase -->

Stub for Strategy L3S2.

<!-- verocase element L3G3 -->
<!-- end verocase -->

Stub for Claim L3G3.

<!-- verocase element L3S3 -->
<!-- end verocase -->

Stub for Strategy L3S3.

<!-- verocase element L3G4 -->
<!-- end verocase -->

Stub for Claim L3G4.

<!-- verocase element L3Edeep -->
<!-- end verocase -->

Stub for Evidence L3Edeep.

<!-- verocase element L3G4b -->
<!-- end verocase -->

Stub for Claim L3G4b.

<!-- verocase element L3G3b -->
<!-- end verocase -->

Stub for Claim L3G3b.

<!-- verocase element L3G3c -->
<!-- end verocase -->

Stub for Claim L3G3c.

<!-- verocase element L3J1 -->
<!-- end verocase -->

Stub for Justification L3J1.

<!-- verocase element L3G2b -->
<!-- end verocase -->

Stub for Claim L3G2b.

<!-- verocase element L3S2b -->
<!-- end verocase -->

Stub for Strategy L3S2b.

<!-- verocase element L3G3d -->
<!-- end verocase -->

Stub for Claim L3G3d.

<!-- verocase element L3G3e -->
<!-- end verocase -->

Stub for Claim L3G3e.

<!-- verocase element L3E2 -->
<!-- end verocase -->

Stub for Evidence L3E2.

<!-- verocase element L3Gbr1 -->
<!-- end verocase -->

Stub for Claim L3Gbr1.

<!-- verocase element L3Gbr1a -->
<!-- end verocase -->

Stub for Claim L3Gbr1a.

<!-- verocase element L3Ebr1 -->
<!-- end verocase -->

Stub for Evidence L3Ebr1.

<!-- verocase element L3Gbr1b -->
<!-- end verocase -->

Stub for Claim L3Gbr1b.

<!-- verocase element L3Gbr2 -->
<!-- end verocase -->

Stub for Claim L3Gbr2.

<!-- verocase element L3Gbr2a -->
<!-- end verocase -->

Stub for Claim L3Gbr2a.

<!-- verocase element L3Ebr2 -->
<!-- end verocase -->

Stub for Evidence L3Ebr2.

<!-- verocase element L3Gbr2b -->
<!-- end verocase -->

Stub for Claim L3Gbr2b.

<!-- verocase element L3Gbr3 -->
<!-- end verocase -->

Stub for Claim L3Gbr3.

<!-- verocase element L3Gbr3a -->
<!-- end verocase -->

Stub for Claim L3Gbr3a.

<!-- verocase element L3Ebr3 -->
<!-- end verocase -->

Stub for Evidence L3Ebr3.

<!-- verocase element L3Gbr3b -->
<!-- end verocase -->

Stub for Claim L3Gbr3b.

<!-- verocase element L3Gbr4 -->
<!-- end verocase -->

Stub for Claim L3Gbr4.

<!-- verocase element L3Gbr4a -->
<!-- end verocase -->

Stub for Claim L3Gbr4a.

<!-- verocase element L3Ebr4 -->
<!-- end verocase -->

Stub for Evidence L3Ebr4.

<!-- verocase element L3Gbr4b -->
<!-- end verocase -->

Stub for Claim L3Gbr4b.

<!-- verocase element L3Gbr5 -->
<!-- end verocase -->

Stub for Claim L3Gbr5.

<!-- verocase element L3Gbr5a -->
<!-- end verocase -->

Stub for Claim L3Gbr5a.

<!-- verocase element L3Ebr5 -->
<!-- end verocase -->

Stub for Evidence L3Ebr5.

<!-- verocase element L3Gbr5b -->
<!-- end verocase -->

Stub for Claim L3Gbr5b.

<!-- verocase element L3Gbr6 -->
<!-- end verocase -->

Stub for Claim L3Gbr6.

<!-- verocase element L3Gbr6a -->
<!-- end verocase -->

Stub for Claim L3Gbr6a.

<!-- verocase element L3Ebr6 -->
<!-- end verocase -->

Stub for Evidence L3Ebr6.

<!-- verocase element L3Gbr6b -->
<!-- end verocase -->

Stub for Claim L3Gbr6b.

<!-- verocase element L3Gbr7 -->
<!-- end verocase -->

Stub for Claim L3Gbr7.

<!-- verocase element L3Gbr7a -->
<!-- end verocase -->

Stub for Claim L3Gbr7a.

<!-- verocase element L3Ebr7 -->
<!-- end verocase -->

Stub for Evidence L3Ebr7.

<!-- verocase element L3Gbr7b -->
<!-- end verocase -->

Stub for Claim L3Gbr7b.

<!-- verocase element L3Gbr8 -->
<!-- end verocase -->

Stub for Claim L3Gbr8.

<!-- verocase element L3Gbr8a -->
<!-- end verocase -->

Stub for Claim L3Gbr8a.

<!-- verocase element L3Ebr8 -->
<!-- end verocase -->

Stub for Evidence L3Ebr8.

<!-- verocase element L3Gbr8b -->
<!-- end verocase -->

Stub for Claim L3Gbr8b.

<!-- verocase element L4top -->
<!-- end verocase -->

Stub for Claim L4top.

<!-- verocase element L4Xctx -->
<!-- end verocase -->

Stub for Context L4Xctx.

<!-- verocase element L4Esh1 -->
<!-- end verocase -->

Stub for Evidence L4Esh1.

<!-- verocase element L4Esh2 -->
<!-- end verocase -->

Stub for Evidence L4Esh2.

<!-- verocase element L4Smain -->
<!-- end verocase -->

Stub for Strategy L4Smain.

<!-- verocase element L4G2 -->
<!-- end verocase -->

Stub for Claim L4G2.

<!-- verocase element L4S2 -->
<!-- end verocase -->

Stub for Strategy L4S2.

<!-- verocase element L4G3 -->
<!-- end verocase -->

Stub for Claim L4G3.

<!-- verocase element L4S3 -->
<!-- end verocase -->

Stub for Strategy L4S3.

<!-- verocase element L4G4 -->
<!-- end verocase -->

Stub for Claim L4G4.

<!-- verocase element L4Edeep -->
<!-- end verocase -->

Stub for Evidence L4Edeep.

<!-- verocase element L4G4b -->
<!-- end verocase -->

Stub for Claim L4G4b.

<!-- verocase element L4G3b -->
<!-- end verocase -->

Stub for Claim L4G3b.

<!-- verocase element L4G3c -->
<!-- end verocase -->

Stub for Claim L4G3c.

<!-- verocase element L4J1 -->
<!-- end verocase -->

Stub for Justification L4J1.

<!-- verocase element L4G2b -->
<!-- end verocase -->

Stub for Claim L4G2b.

<!-- verocase element L4S2b -->
<!-- end verocase -->

Stub for Strategy L4S2b.

<!-- verocase element L4G3d -->
<!-- end verocase -->

Stub for Claim L4G3d.

<!-- verocase element L4G3e -->
<!-- end verocase -->

Stub for Claim L4G3e.

<!-- verocase element L4E2 -->
<!-- end verocase -->

Stub for Evidence L4E2.

<!-- verocase element L4Gbr1 -->
<!-- end verocase -->

Stub for Claim L4Gbr1.

<!-- verocase element L4Gbr1a -->
<!-- end verocase -->

Stub for Claim L4Gbr1a.

<!-- verocase element L4Ebr1 -->
<!-- end verocase -->

Stub for Evidence L4Ebr1.

<!-- verocase element L4Gbr1b -->
<!-- end verocase -->

Stub for Claim L4Gbr1b.

<!-- verocase element L4Gbr2 -->
<!-- end verocase -->

Stub for Claim L4Gbr2.

<!-- verocase element L4Gbr2a -->
<!-- end verocase -->

Stub for Claim L4Gbr2a.

<!-- verocase element L4Ebr2 -->
<!-- end verocase -->

Stub for Evidence L4Ebr2.

<!-- verocase element L4Gbr2b -->
<!-- end verocase -->

Stub for Claim L4Gbr2b.

<!-- verocase element L4Gbr3 -->
<!-- end verocase -->

Stub for Claim L4Gbr3.

<!-- verocase element L4Gbr3a -->
<!-- end verocase -->

Stub for Claim L4Gbr3a.

<!-- verocase element L4Ebr3 -->
<!-- end verocase -->

Stub for Evidence L4Ebr3.

<!-- verocase element L4Gbr3b -->
<!-- end verocase -->

Stub for Claim L4Gbr3b.

<!-- verocase element L4Gbr4 -->
<!-- end verocase -->

Stub for Claim L4Gbr4.

<!-- verocase element L4Gbr4a -->
<!-- end verocase -->

Stub for Claim L4Gbr4a.

<!-- verocase element L4Ebr4 -->
<!-- end verocase -->

Stub for Evidence L4Ebr4.

<!-- verocase element L4Gbr4b -->
<!-- end verocase -->

Stub for Claim L4Gbr4b.

<!-- verocase element L4Gbr5 -->
<!-- end verocase -->

Stub for Claim L4Gbr5.

<!-- verocase element L4Gbr5a -->
<!-- end verocase -->

Stub for Claim L4Gbr5a.

<!-- verocase element L4Ebr5 -->
<!-- end verocase -->

Stub for Evidence L4Ebr5.

<!-- verocase element L4Gbr5b -->
<!-- end verocase -->

Stub for Claim L4Gbr5b.

<!-- verocase element L4Gbr6 -->
<!-- end verocase -->

Stub for Claim L4Gbr6.

<!-- verocase element L4Gbr6a -->
<!-- end verocase -->

Stub for Claim L4Gbr6a.

<!-- verocase element L4Ebr6 -->
<!-- end verocase -->

Stub for Evidence L4Ebr6.

<!-- verocase element L4Gbr6b -->
<!-- end verocase -->

Stub for Claim L4Gbr6b.

<!-- verocase element L4Gbr7 -->
<!-- end verocase -->

Stub for Claim L4Gbr7.

<!-- verocase element L4Gbr7a -->
<!-- end verocase -->

Stub for Claim L4Gbr7a.

<!-- verocase element L4Ebr7 -->
<!-- end verocase -->

Stub for Evidence L4Ebr7.

<!-- verocase element L4Gbr7b -->
<!-- end verocase -->

Stub for Claim L4Gbr7b.

<!-- verocase element L4Gbr8 -->
<!-- end verocase -->

Stub for Claim L4Gbr8.

<!-- verocase element L4Gbr8a -->
<!-- end verocase -->

Stub for Claim L4Gbr8a.

<!-- verocase element L4Ebr8 -->
<!-- end verocase -->

Stub for Evidence L4Ebr8.

<!-- verocase element L4Gbr8b -->
<!-- end verocase -->

Stub for Claim L4Gbr8b.

<!-- verocase element L5top -->
<!-- end verocase -->

Stub for Claim L5top.

<!-- verocase element L5Xctx -->
<!-- end verocase -->

Stub for Context L5Xctx.

<!-- verocase element L5Esh1 -->
<!-- end verocase -->

Stub for Evidence L5Esh1.

<!-- verocase element L5Esh2 -->
<!-- end verocase -->

Stub for Evidence L5Esh2.

<!-- verocase element L5Smain -->
<!-- end verocase -->

Stub for Strategy L5Smain.

<!-- verocase element L5G2 -->
<!-- end verocase -->

Stub for Claim L5G2.

<!-- verocase element L5S2 -->
<!-- end verocase -->

Stub for Strategy L5S2.

<!-- verocase element L5G3 -->
<!-- end verocase -->

Stub for Claim L5G3.

<!-- verocase element L5S3 -->
<!-- end verocase -->

Stub for Strategy L5S3.

<!-- verocase element L5G4 -->
<!-- end verocase -->

Stub for Claim L5G4.

<!-- verocase element L5Edeep -->
<!-- end verocase -->

Stub for Evidence L5Edeep.

<!-- verocase element L5G4b -->
<!-- end verocase -->

Stub for Claim L5G4b.

<!-- verocase element L5G3b -->
<!-- end verocase -->

Stub for Claim L5G3b.

<!-- verocase element L5G3c -->
<!-- end verocase -->

Stub for Claim L5G3c.

<!-- verocase element L5J1 -->
<!-- end verocase -->

Stub for Justification L5J1.

<!-- verocase element L5G2b -->
<!-- end verocase -->

Stub for Claim L5G2b.

<!-- verocase element L5S2b -->
<!-- end verocase -->

Stub for Strategy L5S2b.

<!-- verocase element L5G3d -->
<!-- end verocase -->

Stub for Claim L5G3d.

<!-- verocase element L5G3e -->
<!-- end verocase -->

Stub for Claim L5G3e.

<!-- verocase element L5E2 -->
<!-- end verocase -->

Stub for Evidence L5E2.

<!-- verocase element L5Gbr1 -->
<!-- end verocase -->

Stub for Claim L5Gbr1.

<!-- verocase element L5Gbr1a -->
<!-- end verocase -->

Stub for Claim L5Gbr1a.

<!-- verocase element L5Ebr1 -->
<!-- end verocase -->

Stub for Evidence L5Ebr1.

<!-- verocase element L5Gbr1b -->
<!-- end verocase -->

Stub for Claim L5Gbr1b.

<!-- verocase element L5Gbr2 -->
<!-- end verocase -->

Stub for Claim L5Gbr2.

<!-- verocase element L5Gbr2a -->
<!-- end verocase -->

Stub for Claim L5Gbr2a.

<!-- verocase element L5Ebr2 -->
<!-- end verocase -->

Stub for Evidence L5Ebr2.

<!-- verocase element L5Gbr2b -->
<!-- end verocase -->

Stub for Claim L5Gbr2b.

<!-- verocase element L5Gbr3 -->
<!-- end verocase -->

Stub for Claim L5Gbr3.

<!-- verocase element L5Gbr3a -->
<!-- end verocase -->

Stub for Claim L5Gbr3a.

<!-- verocase element L5Ebr3 -->
<!-- end verocase -->

Stub for Evidence L5Ebr3.

<!-- verocase element L5Gbr3b -->
<!-- end verocase -->

Stub for Claim L5Gbr3b.

<!-- verocase element L5Gbr4 -->
<!-- end verocase -->

Stub for Claim L5Gbr4.

<!-- verocase element L5Gbr4a -->
<!-- end verocase -->

Stub for Claim L5Gbr4a.

<!-- verocase element L5Ebr4 -->
<!-- end verocase -->

Stub for Evidence L5Ebr4.

<!-- verocase element L5Gbr4b -->
<!-- end verocase -->

Stub for Claim L5Gbr4b.

<!-- verocase element L5Gbr5 -->
<!-- end verocase -->

Stub for Claim L5Gbr5.

<!-- verocase element L5Gbr5a -->
<!-- end verocase -->

Stub for Claim L5Gbr5a.

<!-- verocase element L5Ebr5 -->
<!-- end verocase -->

Stub for Evidence L5Ebr5.

<!-- verocase element L5Gbr5b -->
<!-- end verocase -->

Stub for Claim L5Gbr5b.

<!-- verocase element L5Gbr6 -->
<!-- end verocase -->

Stub for Claim L5Gbr6.

<!-- verocase element L5Gbr6a -->
<!-- end verocase -->

Stub for Claim L5Gbr6a.

<!-- verocase element L5Ebr6 -->
<!-- end verocase -->

Stub for Evidence L5Ebr6.

<!-- verocase element L5Gbr6b -->
<!-- end verocase -->

Stub for Claim L5Gbr6b.

<!-- verocase element L5Gbr7 -->
<!-- end verocase -->

Stub for Claim L5Gbr7.

<!-- verocase element L5Gbr7a -->
<!-- end verocase -->

Stub for Claim L5Gbr7a.

<!-- verocase element L5Ebr7 -->
<!-- end verocase -->

Stub for Evidence L5Ebr7.

<!-- verocase element L5Gbr7b -->
<!-- end verocase -->

Stub for Claim L5Gbr7b.

<!-- verocase element L5Gbr8 -->
<!-- end verocase -->

Stub for Claim L5Gbr8.

<!-- verocase element L5Gbr8a -->
<!-- end verocase -->

Stub for Claim L5Gbr8a.

<!-- verocase element L5Ebr8 -->
<!-- end verocase -->

Stub for Evidence L5Ebr8.

<!-- verocase element L5Gbr8b -->
<!-- end verocase -->

Stub for Claim L5Gbr8b.

<!-- verocase element C01top -->
<!-- end verocase -->

Stub for Claim C01top.

<!-- verocase element C01Xctx -->
<!-- end verocase -->

Stub for Context C01Xctx.

<!-- verocase element C01Esh -->
<!-- end verocase -->

Stub for Evidence C01Esh.

<!-- verocase element C01Sass -->
<!-- end verocase -->

Stub for Strategy C01Sass.

<!-- verocase element C01G1 -->
<!-- end verocase -->

Stub for Claim C01G1.

<!-- verocase element C01E1 -->
<!-- end verocase -->

Stub for Evidence C01E1.

<!-- verocase element C01G2 -->
<!-- end verocase -->

Stub for Claim C01G2.

<!-- verocase element C01J1 -->
<!-- end verocase -->

Stub for Justification C01J1.

<!-- verocase element C01G3 -->
<!-- end verocase -->

Stub for Claim C01G3.

<!-- verocase element C01A1 -->
<!-- end verocase -->

Stub for Assumption C01A1.

<!-- verocase element C01E2 -->
<!-- end verocase -->

Stub for Evidence C01E2.

<!-- verocase element C02top -->
<!-- end verocase -->

Stub for Claim C02top.

<!-- verocase element C02Xctx -->
<!-- end verocase -->

Stub for Context C02Xctx.

<!-- verocase element C02Esh -->
<!-- end verocase -->

Stub for Evidence C02Esh.

<!-- verocase element C02Sass -->
<!-- end verocase -->

Stub for Strategy C02Sass.

<!-- verocase element C02G1 -->
<!-- end verocase -->

Stub for Claim C02G1.

<!-- verocase element C02E1 -->
<!-- end verocase -->

Stub for Evidence C02E1.

<!-- verocase element C02G2 -->
<!-- end verocase -->

Stub for Claim C02G2.

<!-- verocase element C02J1 -->
<!-- end verocase -->

Stub for Justification C02J1.

<!-- verocase element C02G3 -->
<!-- end verocase -->

Stub for Claim C02G3.

<!-- verocase element C02A1 -->
<!-- end verocase -->

Stub for Assumption C02A1.

<!-- verocase element C02E2 -->
<!-- end verocase -->

Stub for Evidence C02E2.

<!-- verocase element C03top -->
<!-- end verocase -->

Stub for Claim C03top.

<!-- verocase element C03Xctx -->
<!-- end verocase -->

Stub for Context C03Xctx.

<!-- verocase element C03Esh -->
<!-- end verocase -->

Stub for Evidence C03Esh.

<!-- verocase element C03Sass -->
<!-- end verocase -->

Stub for Strategy C03Sass.

<!-- verocase element C03G1 -->
<!-- end verocase -->

Stub for Claim C03G1.

<!-- verocase element C03E1 -->
<!-- end verocase -->

Stub for Evidence C03E1.

<!-- verocase element C03G2 -->
<!-- end verocase -->

Stub for Claim C03G2.

<!-- verocase element C03J1 -->
<!-- end verocase -->

Stub for Justification C03J1.

<!-- verocase element C03G3 -->
<!-- end verocase -->

Stub for Claim C03G3.

<!-- verocase element C03A1 -->
<!-- end verocase -->

Stub for Assumption C03A1.

<!-- verocase element C03E2 -->
<!-- end verocase -->

Stub for Evidence C03E2.

<!-- verocase element C04top -->
<!-- end verocase -->

Stub for Claim C04top.

<!-- verocase element C04Xctx -->
<!-- end verocase -->

Stub for Context C04Xctx.

<!-- verocase element C04Esh -->
<!-- end verocase -->

Stub for Evidence C04Esh.

<!-- verocase element C04Sass -->
<!-- end verocase -->

Stub for Strategy C04Sass.

<!-- verocase element C04G1 -->
<!-- end verocase -->

Stub for Claim C04G1.

<!-- verocase element C04E1 -->
<!-- end verocase -->

Stub for Evidence C04E1.

<!-- verocase element C04G2 -->
<!-- end verocase -->

Stub for Claim C04G2.

<!-- verocase element C04J1 -->
<!-- end verocase -->

Stub for Justification C04J1.

<!-- verocase element C04G3 -->
<!-- end verocase -->

Stub for Claim C04G3.

<!-- verocase element C04A1 -->
<!-- end verocase -->

Stub for Assumption C04A1.

<!-- verocase element C04E2 -->
<!-- end verocase -->

Stub for Evidence C04E2.

<!-- verocase element C05top -->
<!-- end verocase -->

Stub for Claim C05top.

<!-- verocase element C05Xctx -->
<!-- end verocase -->

Stub for Context C05Xctx.

<!-- verocase element C05Esh -->
<!-- end verocase -->

Stub for Evidence C05Esh.

<!-- verocase element C05Sass -->
<!-- end verocase -->

Stub for Strategy C05Sass.

<!-- verocase element C05G1 -->
<!-- end verocase -->

Stub for Claim C05G1.

<!-- verocase element C05E1 -->
<!-- end verocase -->

Stub for Evidence C05E1.

<!-- verocase element C05G2 -->
<!-- end verocase -->

Stub for Claim C05G2.

<!-- verocase element C05J1 -->
<!-- end verocase -->

Stub for Justification C05J1.

<!-- verocase element C05G3 -->
<!-- end verocase -->

Stub for Claim C05G3.

<!-- verocase element C05A1 -->
<!-- end verocase -->

Stub for Assumption C05A1.

<!-- verocase element C05E2 -->
<!-- end verocase -->

Stub for Evidence C05E2.

<!-- verocase element C06top -->
<!-- end verocase -->

Stub for Claim C06top.

<!-- verocase element C06Xctx -->
<!-- end verocase -->

Stub for Context C06Xctx.

<!-- verocase element C06Esh -->
<!-- end verocase -->

Stub for Evidence C06Esh.

<!-- verocase element C06Sass -->
<!-- end verocase -->

Stub for Strategy C06Sass.

<!-- verocase element C06G1 -->
<!-- end verocase -->

Stub for Claim C06G1.

<!-- verocase element C06E1 -->
<!-- end verocase -->

Stub for Evidence C06E1.

<!-- verocase element C06G2 -->
<!-- end verocase -->

Stub for Claim C06G2.

<!-- verocase element C06J1 -->
<!-- end verocase -->

Stub for Justification C06J1.

<!-- verocase element C06G3 -->
<!-- end verocase -->

Stub for Claim C06G3.

<!-- verocase element C06A1 -->
<!-- end verocase -->

Stub for Assumption C06A1.

<!-- verocase element C06E2 -->
<!-- end verocase -->

Stub for Evidence C06E2.

<!-- verocase element C07top -->
<!-- end verocase -->

Stub for Claim C07top.

<!-- verocase element C07Xctx -->
<!-- end verocase -->

Stub for Context C07Xctx.

<!-- verocase element C07Esh -->
<!-- end verocase -->

Stub for Evidence C07Esh.

<!-- verocase element C07Sass -->
<!-- end verocase -->

Stub for Strategy C07Sass.

<!-- verocase element C07G1 -->
<!-- end verocase -->

Stub for Claim C07G1.

<!-- verocase element C07E1 -->
<!-- end verocase -->

Stub for Evidence C07E1.

<!-- verocase element C07G2 -->
<!-- end verocase -->

Stub for Claim C07G2.

<!-- verocase element C07J1 -->
<!-- end verocase -->

Stub for Justification C07J1.

<!-- verocase element C07G3 -->
<!-- end verocase -->

Stub for Claim C07G3.

<!-- verocase element C07A1 -->
<!-- end verocase -->

Stub for Assumption C07A1.

<!-- verocase element C07E2 -->
<!-- end verocase -->

Stub for Evidence C07E2.

<!-- verocase element C08top -->
<!-- end verocase -->

Stub for Claim C08top.

<!-- verocase element C08Xctx -->
<!-- end verocase -->

Stub for Context C08Xctx.

<!-- verocase element C08Esh -->
<!-- end verocase -->

Stub for Evidence C08Esh.

<!-- verocase element C08Sass -->
<!-- end verocase -->

Stub for Strategy C08Sass.

<!-- verocase element C08G1 -->
<!-- end verocase -->

Stub for Claim C08G1.

<!-- verocase element C08E1 -->
<!-- end verocase -->

Stub for Evidence C08E1.

<!-- verocase element C08G2 -->
<!-- end verocase -->

Stub for Claim C08G2.

<!-- verocase element C08J1 -->
<!-- end verocase -->

Stub for Justification C08J1.

<!-- verocase element C08G3 -->
<!-- end verocase -->

Stub for Claim C08G3.

<!-- verocase element C08A1 -->
<!-- end verocase -->

Stub for Assumption C08A1.

<!-- verocase element C08E2 -->
<!-- end verocase -->

Stub for Evidence C08E2.

<!-- verocase element C09top -->
<!-- end verocase -->

Stub for Claim C09top.

<!-- verocase element C09Xctx -->
<!-- end verocase -->

Stub for Context C09Xctx.

<!-- verocase element C09Esh -->
<!-- end verocase -->

Stub for Evidence C09Esh.

<!-- verocase element C09Sass -->
<!-- end verocase -->

Stub for Strategy C09Sass.

<!-- verocase element C09G1 -->
<!-- end verocase -->

Stub for Claim C09G1.

<!-- verocase element C09E1 -->
<!-- end verocase -->

Stub for Evidence C09E1.

<!-- verocase element C09G2 -->
<!-- end verocase -->

Stub for Claim C09G2.

<!-- verocase element C09J1 -->
<!-- end verocase -->

Stub for Justification C09J1.

<!-- verocase element C09G3 -->
<!-- end verocase -->

Stub for Claim C09G3.

<!-- verocase element C09A1 -->
<!-- end verocase -->

Stub for Assumption C09A1.

<!-- verocase element C09E2 -->
<!-- end verocase -->

Stub for Evidence C09E2.

<!-- verocase element C10top -->
<!-- end verocase -->

Stub for Claim C10top.

<!-- verocase element C10Xctx -->
<!-- end verocase -->

Stub for Context C10Xctx.

<!-- verocase element C10Esh -->
<!-- end verocase -->

Stub for Evidence C10Esh.

<!-- verocase element C10Sass -->
<!-- end verocase -->

Stub for Strategy C10Sass.

<!-- verocase element C10G1 -->
<!-- end verocase -->

Stub for Claim C10G1.

<!-- verocase element C10E1 -->
<!-- end verocase -->

Stub for Evidence C10E1.

<!-- verocase element C10G2 -->
<!-- end verocase -->

Stub for Claim C10G2.

<!-- verocase element C10J1 -->
<!-- end verocase -->

Stub for Justification C10J1.

<!-- verocase element C10G3 -->
<!-- end verocase -->

Stub for Claim C10G3.

<!-- verocase element C10A1 -->
<!-- end verocase -->

Stub for Assumption C10A1.

<!-- verocase element C10E2 -->
<!-- end verocase -->

Stub for Evidence C10E2.

<!-- verocase element C11top -->
<!-- end verocase -->

Stub for Claim C11top.

<!-- verocase element C11Xctx -->
<!-- end verocase -->

Stub for Context C11Xctx.

<!-- verocase element C11Esh -->
<!-- end verocase -->

Stub for Evidence C11Esh.

<!-- verocase element C11Sass -->
<!-- end verocase -->

Stub for Strategy C11Sass.

<!-- verocase element C11G1 -->
<!-- end verocase -->

Stub for Claim C11G1.

<!-- verocase element C11E1 -->
<!-- end verocase -->

Stub for Evidence C11E1.

<!-- verocase element C11G2 -->
<!-- end verocase -->

Stub for Claim C11G2.

<!-- verocase element C11J1 -->
<!-- end verocase -->

Stub for Justification C11J1.

<!-- verocase element C11G3 -->
<!-- end verocase -->

Stub for Claim C11G3.

<!-- verocase element C11A1 -->
<!-- end verocase -->

Stub for Assumption C11A1.

<!-- verocase element C11E2 -->
<!-- end verocase -->

Stub for Evidence C11E2.

<!-- verocase element C12top -->
<!-- end verocase -->

Stub for Claim C12top.

<!-- verocase element C12Xctx -->
<!-- end verocase -->

Stub for Context C12Xctx.

<!-- verocase element C12Esh -->
<!-- end verocase -->

Stub for Evidence C12Esh.

<!-- verocase element C12Sass -->
<!-- end verocase -->

Stub for Strategy C12Sass.

<!-- verocase element C12G1 -->
<!-- end verocase -->

Stub for Claim C12G1.

<!-- verocase element C12E1 -->
<!-- end verocase -->

Stub for Evidence C12E1.

<!-- verocase element C12G2 -->
<!-- end verocase -->

Stub for Claim C12G2.

<!-- verocase element C12J1 -->
<!-- end verocase -->

Stub for Justification C12J1.

<!-- verocase element C12G3 -->
<!-- end verocase -->

Stub for Claim C12G3.

<!-- verocase element C12A1 -->
<!-- end verocase -->

Stub for Assumption C12A1.

<!-- verocase element C12E2 -->
<!-- end verocase -->

Stub for Evidence C12E2.

<!-- verocase element C13top -->
<!-- end verocase -->

Stub for Claim C13top.

<!-- verocase element C13Xctx -->
<!-- end verocase -->

Stub for Context C13Xctx.

<!-- verocase element C13Esh -->
<!-- end verocase -->

Stub for Evidence C13Esh.

<!-- verocase element C13Sass -->
<!-- end verocase -->

Stub for Strategy C13Sass.

<!-- verocase element C13G1 -->
<!-- end verocase -->

Stub for Claim C13G1.

<!-- verocase element C13E1 -->
<!-- end verocase -->

Stub for Evidence C13E1.

<!-- verocase element C13G2 -->
<!-- end verocase -->

Stub for Claim C13G2.

<!-- verocase element C13J1 -->
<!-- end verocase -->

Stub for Justification C13J1.

<!-- verocase element C13G3 -->
<!-- end verocase -->

Stub for Claim C13G3.

<!-- verocase element C13A1 -->
<!-- end verocase -->

Stub for Assumption C13A1.

<!-- verocase element C13E2 -->
<!-- end verocase -->

Stub for Evidence C13E2.

<!-- verocase element C14top -->
<!-- end verocase -->

Stub for Claim C14top.

<!-- verocase element C14Xctx -->
<!-- end verocase -->

Stub for Context C14Xctx.

<!-- verocase element C14Esh -->
<!-- end verocase -->

Stub for Evidence C14Esh.

<!-- verocase element C14Sass -->
<!-- end verocase -->

Stub for Strategy C14Sass.

<!-- verocase element C14G1 -->
<!-- end verocase -->

Stub for Claim C14G1.

<!-- verocase element C14E1 -->
<!-- end verocase -->

Stub for Evidence C14E1.

<!-- verocase element C14G2 -->
<!-- end verocase -->

Stub for Claim C14G2.

<!-- verocase element C14J1 -->
<!-- end verocase -->

Stub for Justification C14J1.

<!-- verocase element C14G3 -->
<!-- end verocase -->

Stub for Claim C14G3.

<!-- verocase element C14A1 -->
<!-- end verocase -->

Stub for Assumption C14A1.

<!-- verocase element C14E2 -->
<!-- end verocase -->

Stub for Evidence C14E2.

<!-- verocase element C15top -->
<!-- end verocase -->

Stub for Claim C15top.

<!-- verocase element C15Xctx -->
<!-- end verocase -->

Stub for Context C15Xctx.

<!-- verocase element C15Esh -->
<!-- end verocase -->

Stub for Evidence C15Esh.

<!-- verocase element C15Sass -->
<!-- end verocase -->

Stub for Strategy C15Sass.

<!-- verocase element C15G1 -->
<!-- end verocase -->

Stub for Claim C15G1.

<!-- verocase element C15E1 -->
<!-- end verocase -->

Stub for Evidence C15E1.

<!-- verocase element C15G2 -->
<!-- end verocase -->

Stub for Claim C15G2.

<!-- verocase element C15J1 -->
<!-- end verocase -->

Stub for Justification C15J1.

<!-- verocase element C15G3 -->
<!-- end verocase -->

Stub for Claim C15G3.

<!-- verocase element C15A1 -->
<!-- end verocase -->

Stub for Assumption C15A1.

<!-- verocase element C15E2 -->
<!-- end verocase -->

Stub for Evidence C15E2.

<!-- verocase element C16top -->
<!-- end verocase -->

Stub for Claim C16top.

<!-- verocase element C16Xctx -->
<!-- end verocase -->

Stub for Context C16Xctx.

<!-- verocase element C16Esh -->
<!-- end verocase -->

Stub for Evidence C16Esh.

<!-- verocase element C16Sass -->
<!-- end verocase -->

Stub for Strategy C16Sass.

<!-- verocase element C16G1 -->
<!-- end verocase -->

Stub for Claim C16G1.

<!-- verocase element C16E1 -->
<!-- end verocase -->

Stub for Evidence C16E1.

<!-- verocase element C16G2 -->
<!-- end verocase -->

Stub for Claim C16G2.

<!-- verocase element C16J1 -->
<!-- end verocase -->

Stub for Justification C16J1.

<!-- verocase element C16G3 -->
<!-- end verocase -->

Stub for Claim C16G3.

<!-- verocase element C16A1 -->
<!-- end verocase -->

Stub for Assumption C16A1.

<!-- verocase element C16E2 -->
<!-- end verocase -->

Stub for Evidence C16E2.

<!-- verocase element C17top -->
<!-- end verocase -->

Stub for Claim C17top.

<!-- verocase element C17Xctx -->
<!-- end verocase -->

Stub for Context C17Xctx.

<!-- verocase element C17Esh -->
<!-- end verocase -->

Stub for Evidence C17Esh.

<!-- verocase element C17Sass -->
<!-- end verocase -->

Stub for Strategy C17Sass.

<!-- verocase element C17G1 -->
<!-- end verocase -->

Stub for Claim C17G1.

<!-- verocase element C17E1 -->
<!-- end verocase -->

Stub for Evidence C17E1.

<!-- verocase element C17G2 -->
<!-- end verocase -->

Stub for Claim C17G2.

<!-- verocase element C17J1 -->
<!-- end verocase -->

Stub for Justification C17J1.

<!-- verocase element C17G3 -->
<!-- end verocase -->

Stub for Claim C17G3.

<!-- verocase element C17A1 -->
<!-- end verocase -->

Stub for Assumption C17A1.

<!-- verocase element C17E2 -->
<!-- end verocase -->

Stub for Evidence C17E2.

<!-- verocase element C18top -->
<!-- end verocase -->

Stub for Claim C18top.

<!-- verocase element C18Xctx -->
<!-- end verocase -->

Stub for Context C18Xctx.

<!-- verocase element C18Esh -->
<!-- end verocase -->

Stub for Evidence C18Esh.

<!-- verocase element C18Sass -->
<!-- end verocase -->

Stub for Strategy C18Sass.

<!-- verocase element C18G1 -->
<!-- end verocase -->

Stub for Claim C18G1.

<!-- verocase element C18E1 -->
<!-- end verocase -->

Stub for Evidence C18E1.

<!-- verocase element C18G2 -->
<!-- end verocase -->

Stub for Claim C18G2.

<!-- verocase element C18J1 -->
<!-- end verocase -->

Stub for Justification C18J1.

<!-- verocase element C18G3 -->
<!-- end verocase -->

Stub for Claim C18G3.

<!-- verocase element C18A1 -->
<!-- end verocase -->

Stub for Assumption C18A1.

<!-- verocase element C18E2 -->
<!-- end verocase -->

Stub for Evidence C18E2.

<!-- verocase element C19top -->
<!-- end verocase -->

Stub for Claim C19top.

<!-- verocase element C19Xctx -->
<!-- end verocase -->

Stub for Context C19Xctx.

<!-- verocase element C19Esh -->
<!-- end verocase -->

Stub for Evidence C19Esh.

<!-- verocase element C19Sass -->
<!-- end verocase -->

Stub for Strategy C19Sass.

<!-- verocase element C19G1 -->
<!-- end verocase -->

Stub for Claim C19G1.

<!-- verocase element C19E1 -->
<!-- end verocase -->

Stub for Evidence C19E1.

<!-- verocase element C19G2 -->
<!-- end verocase -->

Stub for Claim C19G2.

<!-- verocase element C19J1 -->
<!-- end verocase -->

Stub for Justification C19J1.

<!-- verocase element C19G3 -->
<!-- end verocase -->

Stub for Claim C19G3.

<!-- verocase element C19A1 -->
<!-- end verocase -->

Stub for Assumption C19A1.

<!-- verocase element C19E2 -->
<!-- end verocase -->

Stub for Evidence C19E2.

<!-- verocase element C20top -->
<!-- end verocase -->

Stub for Claim C20top.

<!-- verocase element C20Xctx -->
<!-- end verocase -->

Stub for Context C20Xctx.

<!-- verocase element C20Esh -->
<!-- end verocase -->

Stub for Evidence C20Esh.

<!-- verocase element C20Sass -->
<!-- end verocase -->

Stub for Strategy C20Sass.

<!-- verocase element C20G1 -->
<!-- end verocase -->

Stub for Claim C20G1.

<!-- verocase element C20E1 -->
<!-- end verocase -->

Stub for Evidence C20E1.

<!-- verocase element C20G2 -->
<!-- end verocase -->

Stub for Claim C20G2.

<!-- verocase element C20J1 -->
<!-- end verocase -->

Stub for Justification C20J1.

<!-- verocase element C20G3 -->
<!-- end verocase -->

Stub for Claim C20G3.

<!-- verocase element C20A1 -->
<!-- end verocase -->

Stub for Assumption C20A1.

<!-- verocase element C20E2 -->
<!-- end verocase -->

Stub for Evidence C20E2.

<!-- verocase element C21top -->
<!-- end verocase -->

Stub for Claim C21top.

<!-- verocase element C21Xctx -->
<!-- end verocase -->

Stub for Context C21Xctx.

<!-- verocase element C21Esh -->
<!-- end verocase -->

Stub for Evidence C21Esh.

<!-- verocase element C21Sass -->
<!-- end verocase -->

Stub for Strategy C21Sass.

<!-- verocase element C21G1 -->
<!-- end verocase -->

Stub for Claim C21G1.

<!-- verocase element C21E1 -->
<!-- end verocase -->

Stub for Evidence C21E1.

<!-- verocase element C21G2 -->
<!-- end verocase -->

Stub for Claim C21G2.

<!-- verocase element C21J1 -->
<!-- end verocase -->

Stub for Justification C21J1.

<!-- verocase element C21G3 -->
<!-- end verocase -->

Stub for Claim C21G3.

<!-- verocase element C21A1 -->
<!-- end verocase -->

Stub for Assumption C21A1.

<!-- verocase element C21E2 -->
<!-- end verocase -->

Stub for Evidence C21E2.

<!-- verocase element C22top -->
<!-- end verocase -->

Stub for Claim C22top.

<!-- verocase element C22Xctx -->
<!-- end verocase -->

Stub for Context C22Xctx.

<!-- verocase element C22Esh -->
<!-- end verocase -->

Stub for Evidence C22Esh.

<!-- verocase element C22Sass -->
<!-- end verocase -->

Stub for Strategy C22Sass.

<!-- verocase element C22G1 -->
<!-- end verocase -->

Stub for Claim C22G1.

<!-- verocase element C22E1 -->
<!-- end verocase -->

Stub for Evidence C22E1.

<!-- verocase element C22G2 -->
<!-- end verocase -->

Stub for Claim C22G2.

<!-- verocase element C22J1 -->
<!-- end verocase -->

Stub for Justification C22J1.

<!-- verocase element C22G3 -->
<!-- end verocase -->

Stub for Claim C22G3.

<!-- verocase element C22A1 -->
<!-- end verocase -->

Stub for Assumption C22A1.

<!-- verocase element C22E2 -->
<!-- end verocase -->

Stub for Evidence C22E2.

<!-- verocase element C23top -->
<!-- end verocase -->

Stub for Claim C23top.

<!-- verocase element C23Xctx -->
<!-- end verocase -->

Stub for Context C23Xctx.

<!-- verocase element C23Esh -->
<!-- end verocase -->

Stub for Evidence C23Esh.

<!-- verocase element C23Sass -->
<!-- end verocase -->

Stub for Strategy C23Sass.

<!-- verocase element C23G1 -->
<!-- end verocase -->

Stub for Claim C23G1.

<!-- verocase element C23E1 -->
<!-- end verocase -->

Stub for Evidence C23E1.

<!-- verocase element C23G2 -->
<!-- end verocase -->

Stub for Claim C23G2.

<!-- verocase element C23J1 -->
<!-- end verocase -->

Stub for Justification C23J1.

<!-- verocase element C23G3 -->
<!-- end verocase -->

Stub for Claim C23G3.

<!-- verocase element C23A1 -->
<!-- end verocase -->

Stub for Assumption C23A1.

<!-- verocase element C23E2 -->
<!-- end verocase -->

Stub for Evidence C23E2.

<!-- verocase element C24top -->
<!-- end verocase -->

Stub for Claim C24top.

<!-- verocase element C24Xctx -->
<!-- end verocase -->

Stub for Context C24Xctx.

<!-- verocase element C24Esh -->
<!-- end verocase -->

Stub for Evidence C24Esh.

<!-- verocase element C24Sass -->
<!-- end verocase -->

Stub for Strategy C24Sass.

<!-- verocase element C24G1 -->
<!-- end verocase -->

Stub for Claim C24G1.

<!-- verocase element C24E1 -->
<!-- end verocase -->

Stub for Evidence C24E1.

<!-- verocase element C24G2 -->
<!-- end verocase -->

Stub for Claim C24G2.

<!-- verocase element C24J1 -->
<!-- end verocase -->

Stub for Justification C24J1.

<!-- verocase element C24G3 -->
<!-- end verocase -->

Stub for Claim C24G3.

<!-- verocase element C24A1 -->
<!-- end verocase -->

Stub for Assumption C24A1.

<!-- verocase element C24E2 -->
<!-- end verocase -->

Stub for Evidence C24E2.

<!-- verocase element C25top -->
<!-- end verocase -->

Stub for Claim C25top.

<!-- verocase element C25Xctx -->
<!-- end verocase -->

Stub for Context C25Xctx.

<!-- verocase element C25Esh -->
<!-- end verocase -->

Stub for Evidence C25Esh.

<!-- verocase element C25Sass -->
<!-- end verocase -->

Stub for Strategy C25Sass.

<!-- verocase element C25G1 -->
<!-- end verocase -->

Stub for Claim C25G1.

<!-- verocase element C25E1 -->
<!-- end verocase -->

Stub for Evidence C25E1.

<!-- verocase element C25G2 -->
<!-- end verocase -->

Stub for Claim C25G2.

<!-- verocase element C25J1 -->
<!-- end verocase -->

Stub for Justification C25J1.

<!-- verocase element C25G3 -->
<!-- end verocase -->

Stub for Claim C25G3.

<!-- verocase element C25A1 -->
<!-- end verocase -->

Stub for Assumption C25A1.

<!-- verocase element C25E2 -->
<!-- end verocase -->

Stub for Evidence C25E2.

<!-- verocase element C26top -->
<!-- end verocase -->

Stub for Claim C26top.

<!-- verocase element C26Xctx -->
<!-- end verocase -->

Stub for Context C26Xctx.

<!-- verocase element C26Esh -->
<!-- end verocase -->

Stub for Evidence C26Esh.

<!-- verocase element C26Sass -->
<!-- end verocase -->

Stub for Strategy C26Sass.

<!-- verocase element C26G1 -->
<!-- end verocase -->

Stub for Claim C26G1.

<!-- verocase element C26E1 -->
<!-- end verocase -->

Stub for Evidence C26E1.

<!-- verocase element C26G2 -->
<!-- end verocase -->

Stub for Claim C26G2.

<!-- verocase element C26J1 -->
<!-- end verocase -->

Stub for Justification C26J1.

<!-- verocase element C26G3 -->
<!-- end verocase -->

Stub for Claim C26G3.

<!-- verocase element C26A1 -->
<!-- end verocase -->

Stub for Assumption C26A1.

<!-- verocase element C26E2 -->
<!-- end verocase -->

Stub for Evidence C26E2.

<!-- verocase element C27top -->
<!-- end verocase -->

Stub for Claim C27top.

<!-- verocase element C27Xctx -->
<!-- end verocase -->

Stub for Context C27Xctx.

<!-- verocase element C27Esh -->
<!-- end verocase -->

Stub for Evidence C27Esh.

<!-- verocase element C27Sass -->
<!-- end verocase -->

Stub for Strategy C27Sass.

<!-- verocase element C27G1 -->
<!-- end verocase -->

Stub for Claim C27G1.

<!-- verocase element C27E1 -->
<!-- end verocase -->

Stub for Evidence C27E1.

<!-- verocase element C27G2 -->
<!-- end verocase -->

Stub for Claim C27G2.

<!-- verocase element C27J1 -->
<!-- end verocase -->

Stub for Justification C27J1.

<!-- verocase element C27G3 -->
<!-- end verocase -->

Stub for Claim C27G3.

<!-- verocase element C27A1 -->
<!-- end verocase -->

Stub for Assumption C27A1.

<!-- verocase element C27E2 -->
<!-- end verocase -->

Stub for Evidence C27E2.

<!-- verocase element C28top -->
<!-- end verocase -->

Stub for Claim C28top.

<!-- verocase element C28Xctx -->
<!-- end verocase -->

Stub for Context C28Xctx.

<!-- verocase element C28Esh -->
<!-- end verocase -->

Stub for Evidence C28Esh.

<!-- verocase element C28Sass -->
<!-- end verocase -->

Stub for Strategy C28Sass.

<!-- verocase element C28G1 -->
<!-- end verocase -->

Stub for Claim C28G1.

<!-- verocase element C28E1 -->
<!-- end verocase -->

Stub for Evidence C28E1.

<!-- verocase element C28G2 -->
<!-- end verocase -->

Stub for Claim C28G2.

<!-- verocase element C28J1 -->
<!-- end verocase -->

Stub for Justification C28J1.

<!-- verocase element C28G3 -->
<!-- end verocase -->

Stub for Claim C28G3.

<!-- verocase element C28A1 -->
<!-- end verocase -->

Stub for Assumption C28A1.

<!-- verocase element C28E2 -->
<!-- end verocase -->

Stub for Evidence C28E2.

<!-- verocase element C29top -->
<!-- end verocase -->

Stub for Claim C29top.

<!-- verocase element C29Xctx -->
<!-- end verocase -->

Stub for Context C29Xctx.

<!-- verocase element C29Esh -->
<!-- end verocase -->

Stub for Evidence C29Esh.

<!-- verocase element C29Sass -->
<!-- end verocase -->

Stub for Strategy C29Sass.

<!-- verocase element C29G1 -->
<!-- end verocase -->

Stub for Claim C29G1.

<!-- verocase element C29E1 -->
<!-- end verocase -->

Stub for Evidence C29E1.

<!-- verocase element C29G2 -->
<!-- end verocase -->

Stub for Claim C29G2.

<!-- verocase element C29J1 -->
<!-- end verocase -->

Stub for Justification C29J1.

<!-- verocase element C29G3 -->
<!-- end verocase -->

Stub for Claim C29G3.

<!-- verocase element C29A1 -->
<!-- end verocase -->

Stub for Assumption C29A1.

<!-- verocase element C29E2 -->
<!-- end verocase -->

Stub for Evidence C29E2.

<!-- verocase element C30top -->
<!-- end verocase -->

Stub for Claim C30top.

<!-- verocase element C30Xctx -->
<!-- end verocase -->

Stub for Context C30Xctx.

<!-- verocase element C30Esh -->
<!-- end verocase -->

Stub for Evidence C30Esh.

<!-- verocase element C30Sass -->
<!-- end verocase -->

Stub for Strategy C30Sass.

<!-- verocase element C30G1 -->
<!-- end verocase -->

Stub for Claim C30G1.

<!-- verocase element C30E1 -->
<!-- end verocase -->

Stub for Evidence C30E1.

<!-- verocase element C30G2 -->
<!-- end verocase -->

Stub for Claim C30G2.

<!-- verocase element C30J1 -->
<!-- end verocase -->

Stub for Justification C30J1.

<!-- verocase element C30G3 -->
<!-- end verocase -->

Stub for Claim C30G3.

<!-- verocase element C30A1 -->
<!-- end verocase -->

Stub for Assumption C30A1.

<!-- verocase element C30E2 -->
<!-- end verocase -->

Stub for Evidence C30E2.

<!-- verocase element C31top -->
<!-- end verocase -->

Stub for Claim C31top.

<!-- verocase element C31Xctx -->
<!-- end verocase -->

Stub for Context C31Xctx.

<!-- verocase element C31Esh -->
<!-- end verocase -->

Stub for Evidence C31Esh.

<!-- verocase element C31Sass -->
<!-- end verocase -->

Stub for Strategy C31Sass.

<!-- verocase element C31G1 -->
<!-- end verocase -->

Stub for Claim C31G1.

<!-- verocase element C31E1 -->
<!-- end verocase -->

Stub for Evidence C31E1.

<!-- verocase element C31G2 -->
<!-- end verocase -->

Stub for Claim C31G2.

<!-- verocase element C31J1 -->
<!-- end verocase -->

Stub for Justification C31J1.

<!-- verocase element C31G3 -->
<!-- end verocase -->

Stub for Claim C31G3.

<!-- verocase element C31A1 -->
<!-- end verocase -->

Stub for Assumption C31A1.

<!-- verocase element C31E2 -->
<!-- end verocase -->

Stub for Evidence C31E2.

<!-- verocase element C32top -->
<!-- end verocase -->

Stub for Claim C32top.

<!-- verocase element C32Xctx -->
<!-- end verocase -->

Stub for Context C32Xctx.

<!-- verocase element C32Esh -->
<!-- end verocase -->

Stub for Evidence C32Esh.

<!-- verocase element C32Sass -->
<!-- end verocase -->

Stub for Strategy C32Sass.

<!-- verocase element C32G1 -->
<!-- end verocase -->

Stub for Claim C32G1.

<!-- verocase element C32E1 -->
<!-- end verocase -->

Stub for Evidence C32E1.

<!-- verocase element C32G2 -->
<!-- end verocase -->

Stub for Claim C32G2.

<!-- verocase element C32J1 -->
<!-- end verocase -->

Stub for Justification C32J1.

<!-- verocase element C32G3 -->
<!-- end verocase -->

Stub for Claim C32G3.

<!-- verocase element C32A1 -->
<!-- end verocase -->

Stub for Assumption C32A1.

<!-- verocase element C32E2 -->
<!-- end verocase -->

Stub for Evidence C32E2.

<!-- verocase element C33top -->
<!-- end verocase -->

Stub for Claim C33top.

<!-- verocase element C33Xctx -->
<!-- end verocase -->

Stub for Context C33Xctx.

<!-- verocase element C33Esh -->
<!-- end verocase -->

Stub for Evidence C33Esh.

<!-- verocase element C33Sass -->
<!-- end verocase -->

Stub for Strategy C33Sass.

<!-- verocase element C33G1 -->
<!-- end verocase -->

Stub for Claim C33G1.

<!-- verocase element C33E1 -->
<!-- end verocase -->

Stub for Evidence C33E1.

<!-- verocase element C33G2 -->
<!-- end verocase -->

Stub for Claim C33G2.

<!-- verocase element C33J1 -->
<!-- end verocase -->

Stub for Justification C33J1.

<!-- verocase element C33G3 -->
<!-- end verocase -->

Stub for Claim C33G3.

<!-- verocase element C33A1 -->
<!-- end verocase -->

Stub for Assumption C33A1.

<!-- verocase element C33E2 -->
<!-- end verocase -->

Stub for Evidence C33E2.

<!-- verocase element C34top -->
<!-- end verocase -->

Stub for Claim C34top.

<!-- verocase element C34Xctx -->
<!-- end verocase -->

Stub for Context C34Xctx.

<!-- verocase element C34Esh -->
<!-- end verocase -->

Stub for Evidence C34Esh.

<!-- verocase element C34Sass -->
<!-- end verocase -->

Stub for Strategy C34Sass.

<!-- verocase element C34G1 -->
<!-- end verocase -->

Stub for Claim C34G1.

<!-- verocase element C34E1 -->
<!-- end verocase -->

Stub for Evidence C34E1.

<!-- verocase element C34G2 -->
<!-- end verocase -->

Stub for Claim C34G2.

<!-- verocase element C34J1 -->
<!-- end verocase -->

Stub for Justification C34J1.

<!-- verocase element C34G3 -->
<!-- end verocase -->

Stub for Claim C34G3.

<!-- verocase element C34A1 -->
<!-- end verocase -->

Stub for Assumption C34A1.

<!-- verocase element C34E2 -->
<!-- end verocase -->

Stub for Evidence C34E2.

<!-- verocase element C35top -->
<!-- end verocase -->

Stub for Claim C35top.

<!-- verocase element C35Xctx -->
<!-- end verocase -->

Stub for Context C35Xctx.

<!-- verocase element C35Esh -->
<!-- end verocase -->

Stub for Evidence C35Esh.

<!-- verocase element C35Sass -->
<!-- end verocase -->

Stub for Strategy C35Sass.

<!-- verocase element C35G1 -->
<!-- end verocase -->

Stub for Claim C35G1.

<!-- verocase element C35E1 -->
<!-- end verocase -->

Stub for Evidence C35E1.

<!-- verocase element C35G2 -->
<!-- end verocase -->

Stub for Claim C35G2.

<!-- verocase element C35J1 -->
<!-- end verocase -->

Stub for Justification C35J1.

<!-- verocase element C35G3 -->
<!-- end verocase -->

Stub for Claim C35G3.

<!-- verocase element C35A1 -->
<!-- end verocase -->

Stub for Assumption C35A1.

<!-- verocase element C35E2 -->
<!-- end verocase -->

Stub for Evidence C35E2.

<!-- verocase element C36top -->
<!-- end verocase -->

Stub for Claim C36top.

<!-- verocase element C36Xctx -->
<!-- end verocase -->

Stub for Context C36Xctx.

<!-- verocase element C36Esh -->
<!-- end verocase -->

Stub for Evidence C36Esh.

<!-- verocase element C36Sass -->
<!-- end verocase -->

Stub for Strategy C36Sass.

<!-- verocase element C36G1 -->
<!-- end verocase -->

Stub for Claim C36G1.

<!-- verocase element C36E1 -->
<!-- end verocase -->

Stub for Evidence C36E1.

<!-- verocase element C36G2 -->
<!-- end verocase -->

Stub for Claim C36G2.

<!-- verocase element C36J1 -->
<!-- end verocase -->

Stub for Justification C36J1.

<!-- verocase element C36G3 -->
<!-- end verocase -->

Stub for Claim C36G3.

<!-- verocase element C36A1 -->
<!-- end verocase -->

Stub for Assumption C36A1.

<!-- verocase element C36E2 -->
<!-- end verocase -->

Stub for Evidence C36E2.

<!-- verocase element C37top -->
<!-- end verocase -->

Stub for Claim C37top.

<!-- verocase element C37Xctx -->
<!-- end verocase -->

Stub for Context C37Xctx.

<!-- verocase element C37Esh -->
<!-- end verocase -->

Stub for Evidence C37Esh.

<!-- verocase element C37Sass -->
<!-- end verocase -->

Stub for Strategy C37Sass.

<!-- verocase element C37G1 -->
<!-- end verocase -->

Stub for Claim C37G1.

<!-- verocase element C37E1 -->
<!-- end verocase -->

Stub for Evidence C37E1.

<!-- verocase element C37G2 -->
<!-- end verocase -->

Stub for Claim C37G2.

<!-- verocase element C37J1 -->
<!-- end verocase -->

Stub for Justification C37J1.

<!-- verocase element C37G3 -->
<!-- end verocase -->

Stub for Claim C37G3.

<!-- verocase element C37A1 -->
<!-- end verocase -->

Stub for Assumption C37A1.

<!-- verocase element C37E2 -->
<!-- end verocase -->

Stub for Evidence C37E2.

<!-- verocase element C38top -->
<!-- end verocase -->

Stub for Claim C38top.

<!-- verocase element C38Xctx -->
<!-- end verocase -->

Stub for Context C38Xctx.

<!-- verocase element C38Esh -->
<!-- end verocase -->

Stub for Evidence C38Esh.

<!-- verocase element C38Sass -->
<!-- end verocase -->

Stub for Strategy C38Sass.

<!-- verocase element C38G1 -->
<!-- end verocase -->

Stub for Claim C38G1.

<!-- verocase element C38E1 -->
<!-- end verocase -->

Stub for Evidence C38E1.

<!-- verocase element C38G2 -->
<!-- end verocase -->

Stub for Claim C38G2.

<!-- verocase element C38J1 -->
<!-- end verocase -->

Stub for Justification C38J1.

<!-- verocase element C38G3 -->
<!-- end verocase -->

Stub for Claim C38G3.

<!-- verocase element C38A1 -->
<!-- end verocase -->

Stub for Assumption C38A1.

<!-- verocase element C38E2 -->
<!-- end verocase -->

Stub for Evidence C38E2.

<!-- verocase element C39top -->
<!-- end verocase -->

Stub for Claim C39top.

<!-- verocase element C39Xctx -->
<!-- end verocase -->

Stub for Context C39Xctx.

<!-- verocase element C39Esh -->
<!-- end verocase -->

Stub for Evidence C39Esh.

<!-- verocase element C39Sass -->
<!-- end verocase -->

Stub for Strategy C39Sass.

<!-- verocase element C39G1 -->
<!-- end verocase -->

Stub for Claim C39G1.

<!-- verocase element C39E1 -->
<!-- end verocase -->

Stub for Evidence C39E1.

<!-- verocase element C39G2 -->
<!-- end verocase -->

Stub for Claim C39G2.

<!-- verocase element C39J1 -->
<!-- end verocase -->

Stub for Justification C39J1.

<!-- verocase element C39G3 -->
<!-- end verocase -->

Stub for Claim C39G3.

<!-- verocase element C39A1 -->
<!-- end verocase -->

Stub for Assumption C39A1.

<!-- verocase element C39E2 -->
<!-- end verocase -->

Stub for Evidence C39E2.

<!-- verocase element C40top -->
<!-- end verocase -->

Stub for Claim C40top.

<!-- verocase element C40Xctx -->
<!-- end verocase -->

Stub for Context C40Xctx.

<!-- verocase element C40Esh -->
<!-- end verocase -->

Stub for Evidence C40Esh.

<!-- verocase element C40Sass -->
<!-- end verocase -->

Stub for Strategy C40Sass.

<!-- verocase element C40G1 -->
<!-- end verocase -->

Stub for Claim C40G1.

<!-- verocase element C40E1 -->
<!-- end verocase -->

Stub for Evidence C40E1.

<!-- verocase element C40G2 -->
<!-- end verocase -->

Stub for Claim C40G2.

<!-- verocase element C40J1 -->
<!-- end verocase -->

Stub for Justification C40J1.

<!-- verocase element C40G3 -->
<!-- end verocase -->

Stub for Claim C40G3.

<!-- verocase element C40A1 -->
<!-- end verocase -->

Stub for Assumption C40A1.

<!-- verocase element C40E2 -->
<!-- end verocase -->

Stub for Evidence C40E2.

<!-- verocase element C41top -->
<!-- end verocase -->

Stub for Claim C41top.

<!-- verocase element C41Xctx -->
<!-- end verocase -->

Stub for Context C41Xctx.

<!-- verocase element C41Esh -->
<!-- end verocase -->

Stub for Evidence C41Esh.

<!-- verocase element C41Sass -->
<!-- end verocase -->

Stub for Strategy C41Sass.

<!-- verocase element C41G1 -->
<!-- end verocase -->

Stub for Claim C41G1.

<!-- verocase element C41E1 -->
<!-- end verocase -->

Stub for Evidence C41E1.

<!-- verocase element C41G2 -->
<!-- end verocase -->

Stub for Claim C41G2.

<!-- verocase element C41J1 -->
<!-- end verocase -->

Stub for Justification C41J1.

<!-- verocase element C41G3 -->
<!-- end verocase -->

Stub for Claim C41G3.

<!-- verocase element C41A1 -->
<!-- end verocase -->

Stub for Assumption C41A1.

<!-- verocase element C41E2 -->
<!-- end verocase -->

Stub for Evidence C41E2.

<!-- verocase element C42top -->
<!-- end verocase -->

Stub for Claim C42top.

<!-- verocase element C42Xctx -->
<!-- end verocase -->

Stub for Context C42Xctx.

<!-- verocase element C42Esh -->
<!-- end verocase -->

Stub for Evidence C42Esh.

<!-- verocase element C42Sass -->
<!-- end verocase -->

Stub for Strategy C42Sass.

<!-- verocase element C42G1 -->
<!-- end verocase -->

Stub for Claim C42G1.

<!-- verocase element C42E1 -->
<!-- end verocase -->

Stub for Evidence C42E1.

<!-- verocase element C42G2 -->
<!-- end verocase -->

Stub for Claim C42G2.

<!-- verocase element C42J1 -->
<!-- end verocase -->

Stub for Justification C42J1.

<!-- verocase element C42G3 -->
<!-- end verocase -->

Stub for Claim C42G3.

<!-- verocase element C42A1 -->
<!-- end verocase -->

Stub for Assumption C42A1.

<!-- verocase element C42E2 -->
<!-- end verocase -->

Stub for Evidence C42E2.

<!-- verocase element C43top -->
<!-- end verocase -->

Stub for Claim C43top.

<!-- verocase element C43Xctx -->
<!-- end verocase -->

Stub for Context C43Xctx.

<!-- verocase element C43Esh -->
<!-- end verocase -->

Stub for Evidence C43Esh.

<!-- verocase element C43Sass -->
<!-- end verocase -->

Stub for Strategy C43Sass.

<!-- verocase element C43G1 -->
<!-- end verocase -->

Stub for Claim C43G1.

<!-- verocase element C43E1 -->
<!-- end verocase -->

Stub for Evidence C43E1.

<!-- verocase element C43G2 -->
<!-- end verocase -->

Stub for Claim C43G2.

<!-- verocase element C43J1 -->
<!-- end verocase -->

Stub for Justification C43J1.

<!-- verocase element C43G3 -->
<!-- end verocase -->

Stub for Claim C43G3.

<!-- verocase element C43A1 -->
<!-- end verocase -->

Stub for Assumption C43A1.

<!-- verocase element C43E2 -->
<!-- end verocase -->

Stub for Evidence C43E2.

<!-- verocase element C44top -->
<!-- end verocase -->

Stub for Claim C44top.

<!-- verocase element C44Xctx -->
<!-- end verocase -->

Stub for Context C44Xctx.

<!-- verocase element C44Esh -->
<!-- end verocase -->

Stub for Evidence C44Esh.

<!-- verocase element C44Sass -->
<!-- end verocase -->

Stub for Strategy C44Sass.

<!-- verocase element C44G1 -->
<!-- end verocase -->

Stub for Claim C44G1.

<!-- verocase element C44E1 -->
<!-- end verocase -->

Stub for Evidence C44E1.

<!-- verocase element C44G2 -->
<!-- end verocase -->

Stub for Claim C44G2.

<!-- verocase element C44J1 -->
<!-- end verocase -->

Stub for Justification C44J1.

<!-- verocase element C44G3 -->
<!-- end verocase -->

Stub for Claim C44G3.

<!-- verocase element C44A1 -->
<!-- end verocase -->

Stub for Assumption C44A1.

<!-- verocase element C44E2 -->
<!-- end verocase -->

Stub for Evidence C44E2.

<!-- verocase element C45top -->
<!-- end verocase -->

Stub for Claim C45top.

<!-- verocase element C45Xctx -->
<!-- end verocase -->

Stub for Context C45Xctx.

<!-- verocase element C45Esh -->
<!-- end verocase -->

Stub for Evidence C45Esh.

<!-- verocase element C45Sass -->
<!-- end verocase -->

Stub for Strategy C45Sass.

<!-- verocase element C45G1 -->
<!-- end verocase -->

Stub for Claim C45G1.

<!-- verocase element C45E1 -->
<!-- end verocase -->

Stub for Evidence C45E1.

<!-- verocase element C45G2 -->
<!-- end verocase -->

Stub for Claim C45G2.

<!-- verocase element C45J1 -->
<!-- end verocase -->

Stub for Justification C45J1.

<!-- verocase element C45G3 -->
<!-- end verocase -->

Stub for Claim C45G3.

<!-- verocase element C45A1 -->
<!-- end verocase -->

Stub for Assumption C45A1.

<!-- verocase element C45E2 -->
<!-- end verocase -->

Stub for Evidence C45E2.

